﻿# Copyright (c) CloudAssert LLC. All rights reserved.
# Remove-GalleryPackages.ps1 5.11.251.0 2016-11-04 10:37:08

#requires -Version 4.0
#requires -Module AzureRM
#requires -Module AzureStack

<#
.SYNOPSIS
   Publishes Azure Package (*.azpkg) files to Marketplace (Gallery) in Azure Stack environment.
#>
[CmdletBinding()]
param
(
    [Parameter(Mandatory=$true, HelpMessage="Azure Active Directory tenant directory name.")]
    [string]$AadTenantDirectoryName,

    [Parameter(Mandatory=$true, HelpMessage="Azure Stack Service Admin account credential.")]
    [PSCredential]$azCredential,

    [Parameter(Mandatory=$true, HelpMessage="The GUID used to identify this deployment for telemetry purposes.")]
    [guid]$DeploymentId,
	
	[Parameter(Mandatory=$true, HelpMessage="Azure Stack Admin ARM Endpoint URL")]
	[string]$AdminArmEndpoint
)

Import-Module -Name AzureRM -RequiredVersion 1.2.10 -ErrorAction Stop -Verbose:$false
Import-Module -Name AzureStack -RequiredVersion 1.2.10 -ErrorAction Stop -Verbose:$false
Import-Module -Name "$PSScriptRoot\Common.psm1" -ErrorAction Stop -Verbose:$false

# NOTE: $azCredential = New-Object System.Management.Automation.PSCredential("", (ConvertTo-SecureString -String "" -AsPlainText -Force))

#-----------------------------------------------------------------------------------------------------------------------
# Main

$stopwatch = [System.Diagnostics.Stopwatch]::StartNew()

$scriptName = $MyInvocation.MyCommand.Name
$startTime = [System.DateTimeOffset]::Now
Write-Verbose -Message "Executing Script $scriptName at $startTime" -Verbose
Write-Verbose -Message "Using Parameters: " -Verbose
Write-Verbose -Message $($PSBoundParameters | ConvertTo-Json)  -Verbose

# Telemetry
$deploymentGUID = $DeploymentId # (Get-WmiObject Win32_ComputerSystemProduct).UUID
$startTime = [System.DateTimeOffset]::Now
#Trace-DeploymentInternal -DeploymentGUID $deploymentGUID -Step "Publish-GalleryPackages.ps1 5.11.251.0" -StartTime $startTime -Status 'Success' -LogMessage "Publish CloudAssert.CABilling provider gallery packages started."

$azEnvironment = Get-AzureStackEnvironment -AadTenantDirectoryName $AadTenantDirectoryName -EnvironmentName "AzureStack" -AdminArmEndpoint $AdminArmEndpoint
$azAccount = Initialize-AzureStackEnvironment -AadTenantDirectoryName $AadTenantDirectoryName -EnvironmentName "AzureStack" -azCredential $azCredential -AdminArmEndpoint $AdminArmEndpoint

# NOTE: Select default subscription if the account contains multiple subscriptions.
$azSubscription = Get-AzureRmSubscription -SubscriptionName "Default Provider Subscription" -ErrorAction Stop
$azSubscription | Select-AzureRmSubscription | Out-Null
Write-Verbose -Message "Using subscription: '$($azSubscription.SubscriptionName)'" -Verbose

$galleryItems = Get-AzureRMGalleryItem -Verbose
foreach ($galleryItem in $galleryItems)
{
    $name = $galleryItem.Name
    if ($name -notlike '*CloudAssert.Csp*') { 
        continue 
    }
    try {
        Write-Verbose -Message "Removing Azure Stack Gallery item $name" -Verbose
        #Remove-AzureRMgalleryitem -Name $name -Verbose
    } catch [Exception] {
        Write-Error "Failed to remove Azure Stack Gallery item $name . Error $_"
    }
}

# Telemetry
$endTime = [System.DateTimeOffset]::Now
#Trace-DeploymentInternal -DeploymentGUID $deploymentGUID -Step "Publish-GalleryPackages.ps1 5.11.251.0" -StartTime $startTime -EndTime $endTime -Status 'Success' -LogMessage "Publish CloudAssert.CABilling provider gallery packages completed."